[TODO: write documentation for this plugin.] { "name": "SearchBioImageModelZoo", "type": "web-python", "version": "0.1.0", "description": "BioImage.IO Chatbot Extension for getting information about models, applications, datasets, etc. in the BioImage Model Zoo.", "tags": [], "ui": "", "cover": "", "inputs": null, "outputs": null, "flags": [], "icon": "extension", "api_version": "0.1.8", "env": "", "permissions": [], "requirements": ["pydantic"], "dependencies": [] }